@@ -30,12 +30,18 @@ File generate_pre.h
 #include <QSet>
 #include <QHash>
 #include <QList>
+#include <QLinkedList>
+#include <QPair>
 
 #include <QTextStream>
 
 class QWidget;
 
-bool compareFunctionGeneratePre(int i, int j);
+inline bool findEquivalentSubgroupsCompareFunction(int i1, int i2);
+
+inline bool compareFunctionGeneratePre(int i, int j);
+
+inline bool compareFunctionGeneratePreWithGroupedActivities(int i, int j);
 
 extern int permutation[MAX_ACTIVITIES]; //the permutation matrix to obtain activities in
 //decreasing difficulty order
@@ -424,6 +430,7 @@ bool computeSubgroupsIntervalMaxDaysPerWeek(QWidget* parent);
 //2017-02-06
 extern int teachersMaxSpanPerDayMaxSpan[MAX_TEACHERS]; //-1 for not existing
 extern double teachersMaxSpanPerDayPercentages[MAX_TEACHERS]; //-1 for not existing
+extern bool teachersMaxSpanPerDayAllowOneDayExceptionPlusOne[MAX_TEACHERS];
 
 extern int teachersMinRestingHoursCircularMinHours[MAX_TEACHERS]; //-1 for not existing
 extern double teachersMinRestingHoursCircularPercentages[MAX_TEACHERS]; //-1 for not existing
@@ -466,6 +473,8 @@ extern Matrix1D<QList<int> > activitiesHomeRoomsHomeRooms;
 extern double activitiesHomeRoomsPercentage[MAX_ACTIVITIES];
 extern bool unspecifiedHomeRoom[MAX_ACTIVITIES];
 
+extern Matrix1D<QSet<int> > preferredRealRooms;
+
 bool computeActivitiesRoomsPreferences(QWidget* parent);
 ////////END   rooms
 
@@ -497,6 +506,33 @@ bool computeMaxBuildingChangesPerWeekForTeachers(QWidget* parent);
 ////////END   buildings
 
 
+////////BEGIN rooms
+extern double maxRoomChangesPerDayForStudentsPercentages[MAX_TOTAL_SUBGROUPS];
+extern int maxRoomChangesPerDayForStudentsMaxChanges[MAX_TOTAL_SUBGROUPS];
+bool computeMaxRoomChangesPerDayForStudents(QWidget* parent);
+
+extern double minGapsBetweenRoomChangesForStudentsPercentages[MAX_TOTAL_SUBGROUPS];
+extern int minGapsBetweenRoomChangesForStudentsMinGaps[MAX_TOTAL_SUBGROUPS];
+bool computeMinGapsBetweenRoomChangesForStudents(QWidget* parent);
+
+extern double maxRoomChangesPerDayForTeachersPercentages[MAX_TEACHERS];
+extern int maxRoomChangesPerDayForTeachersMaxChanges[MAX_TEACHERS];
+bool computeMaxRoomChangesPerDayForTeachers(QWidget* parent);
+
+extern double minGapsBetweenRoomChangesForTeachersPercentages[MAX_TEACHERS];
+extern int minGapsBetweenRoomChangesForTeachersMinGaps[MAX_TEACHERS];
+bool computeMinGapsBetweenRoomChangesForTeachers(QWidget* parent);
+
+extern double maxRoomChangesPerWeekForStudentsPercentages[MAX_TOTAL_SUBGROUPS];
+extern int maxRoomChangesPerWeekForStudentsMaxChanges[MAX_TOTAL_SUBGROUPS];
+bool computeMaxRoomChangesPerWeekForStudents(QWidget* parent);
+
+extern double maxRoomChangesPerWeekForTeachersPercentages[MAX_TEACHERS];
+extern int maxRoomChangesPerWeekForTeachersMaxChanges[MAX_TEACHERS];
+bool computeMaxRoomChangesPerWeekForTeachers(QWidget* parent);
+////////END   rooms
+
+
 extern Matrix1D<QList<int> > mustComputeTimetableSubgroups;
 extern Matrix1D<QList<int> > mustComputeTimetableTeachers;
 extern bool mustComputeTimetableSubgroup[MAX_TOTAL_SUBGROUPS];
@@ -522,11 +558,35 @@ public:
 	int maxOccupiedTimeSlots;
 };
 
-extern QList<ActivitiesOccupyMaxTimeSlotsFromSelection_item> aomtsList;
+//The next variable should not be a QVector!!!
+//We need the references to the elements to be valid, so we need this to be a QLinkedList
+//(or a QList, but make sure it allocates on the heap, which might not be always true).
+extern QLinkedList<ActivitiesOccupyMaxTimeSlotsFromSelection_item> aomtsList;
 extern Matrix1D<QList<ActivitiesOccupyMaxTimeSlotsFromSelection_item*> > aomtsListForActivity;
 
 bool computeActivitiesOccupyMaxTimeSlotsFromSelection(QWidget* parent);
 
+//2019-11-16 - Constraint activities occupy min time slots from selection
+
+class ActivitiesOccupyMinTimeSlotsFromSelection_item
+{
+public:
+	//double weight; -> must be 100.0%
+	QList<int> activitiesList;
+	QSet<int> activitiesSet;
+	QList<int> selectedTimeSlotsList;
+	QSet<int> selectedTimeSlotsSet;
+	int minOccupiedTimeSlots;
+};
+
+//The next variable should not be a QVector!!!
+//We need the references to the elements to be valid, so we need this to be a QLinkedList
+//(or a QList, but make sure it allocates on the heap, which might not be always true).
+extern QLinkedList<ActivitiesOccupyMinTimeSlotsFromSelection_item> aomintsList;
+extern Matrix1D<QList<ActivitiesOccupyMinTimeSlotsFromSelection_item*> > aomintsListForActivity;
+
+bool computeActivitiesOccupyMinTimeSlotsFromSelection(QWidget* parent);
+
 //2011-09-30 - Constraint activities max simultaneous in selected time slots
 
 class ActivitiesMaxSimultaneousInSelectedTimeSlots_item
@@ -540,12 +600,42 @@ public:
 	int maxSimultaneous;
 };
 
-extern QList<ActivitiesMaxSimultaneousInSelectedTimeSlots_item> amsistsList;
+//The next variable should not be a QVector!!!
+//We need the references to the elements to be valid, so we need this to be a QLinkedList
+//(or a QList, but make sure it allocates on the heap, which might not be always true).
+extern QLinkedList<ActivitiesMaxSimultaneousInSelectedTimeSlots_item> amsistsList;
 extern Matrix1D<QList<ActivitiesMaxSimultaneousInSelectedTimeSlots_item*> > amsistsListForActivity;
 
 bool computeActivitiesMaxSimultaneousInSelectedTimeSlots(QWidget* parent);
 
-extern bool haveActivitiesOccupyOrSimultaneousConstraints;
+//2019-11-16 - Constraint activities min simultaneous in selected time slots
+
+class ActivitiesMinSimultaneousInSelectedTimeSlots_item
+{
+public:
+	//double weight; -> must be 100.0%
+	QList<int> activitiesList;
+	QSet<int> activitiesSet;
+	QList<int> selectedTimeSlotsList;
+	QSet<int> selectedTimeSlotsSet;
+	int minSimultaneous;
+	
+	bool allowEmptySlots;
+};
+
+//The next variable should not be a QVector!!!
+//We need the references to the elements to be valid, so we need this to be a QLinkedList
+//(or a QList, but make sure it allocates on the heap, which might not be always true).
+extern QLinkedList<ActivitiesMinSimultaneousInSelectedTimeSlots_item> aminsistsList;
+extern Matrix1D<QList<ActivitiesMinSimultaneousInSelectedTimeSlots_item*> > aminsistsListForActivity;
+
+bool computeActivitiesMinSimultaneousInSelectedTimeSlots(QWidget* parent);
+
+extern bool haveActivitiesOccupyMaxConstraints;
+extern bool activityHasOccupyMaxConstraints[MAX_ACTIVITIES];
+
+extern bool haveActivitiesMaxSimultaneousConstraints;
+extern bool activityHasMaxSimultaneousConstraints[MAX_ACTIVITIES];
 
 //2019-06-08 - Constraint students (set) min gaps between ordered pair of activity tags
 
@@ -558,7 +648,10 @@ public:
 	int secondActivityTag;
 };
 
-extern QList<StudentsMinGapsBetweenOrderedPairOfActivityTags_item> smgbopoatList;
+//The next variable should not be a QVector!!!
+//We need the references to the elements to be valid, so we need this to be a QLinkedList
+//(or a QList, but make sure it allocates on the heap, which might not be always true).
+extern QLinkedList<StudentsMinGapsBetweenOrderedPairOfActivityTags_item> smgbopoatList;
 extern Matrix1D<QList<StudentsMinGapsBetweenOrderedPairOfActivityTags_item*> > smgbopoatListForActivity;
 
 bool computeStudentsMinGapsBetweenOrderedPairOfActivityTags(QWidget* parent);
@@ -574,7 +667,10 @@ public:
 	int secondActivityTag;
 };
 
-extern QList<TeachersMinGapsBetweenOrderedPairOfActivityTags_item> tmgbopoatList;
+//The next variable should not be a QVector!!!
+//We need the references to the elements to be valid, so we need this to be a QLinkedList
+//(or a QList, but make sure it allocates on the heap, which might not be always true).
+extern QLinkedList<TeachersMinGapsBetweenOrderedPairOfActivityTags_item> tmgbopoatList;
 extern Matrix1D<QList<TeachersMinGapsBetweenOrderedPairOfActivityTags_item*> > tmgbopoatListForActivity;
 
 bool computeTeachersMinGapsBetweenOrderedPairOfActivityTags(QWidget* parent);
@@ -590,7 +686,10 @@ public:
 	int maxDifferentRooms;
 };
 
-extern QList<ActivitiesOccupyMaxDifferentRooms_item> aomdrList;
+//The next variable should not be a QVector!!!
+//We need the references to the elements to be valid, so we need this to be a QLinkedList
+//(or a QList, but make sure it allocates on the heap, which might not be always true).
+extern QLinkedList<ActivitiesOccupyMaxDifferentRooms_item> aomdrList;
 extern Matrix1D<QList<ActivitiesOccupyMaxDifferentRooms_item*> > aomdrListForActivity;
 
 bool computeActivitiesOccupyMaxDifferentRooms(QWidget* parent);
@@ -605,13 +704,56 @@ public:
 	QSet<int> activitiesSet;
 };
 
-extern QList<ActivitiesSameRoomIfConsecutive_item> asricList;
+//The next variable should not be a QVector!!!
+//We need the references to the elements to be valid, so we need this to be a QLinkedList
+//(or a QList, but make sure it allocates on the heap, which might not be always true).
+extern QLinkedList<ActivitiesSameRoomIfConsecutive_item> asricList;
 extern Matrix1D<QList<ActivitiesSameRoomIfConsecutive_item*> > asricListForActivity;
 
 bool computeActivitiesSameRoomIfConsecutive(QWidget* parent);
 
 /////////////////////////////////////////////////////////////////////////
 
+//2019-11-20
+class SubgroupActivityTagMinHoursDaily_item
+{
+public:
+	int activityTag;
+	int minHoursDaily;
+	bool allowEmptyDays;
+	int durationOfActivitiesWithActivityTagForSubgroup;
+};
+
+//The next variable should not be a QVector!!!
+//We need the references to the elements to be valid, so we need this to be a QLinkedList
+//(or a QList, but make sure it allocates on the heap, which might not be always true).
+extern QLinkedList<SubgroupActivityTagMinHoursDaily_item> satmhdList;
+extern Matrix1D<QList<SubgroupActivityTagMinHoursDaily_item*> > satmhdListForSubgroup;
+extern bool haveStudentsActivityTagMinHoursDaily;
+
+bool computeStudentsActivityTagMinHoursDaily(QWidget* parent);
+
+//2019-11-20
+class TeacherActivityTagMinHoursDaily_item
+{
+public:
+	int activityTag;
+	int minHoursDaily;
+	bool allowEmptyDays;
+	int durationOfActivitiesWithActivityTagForTeacher;
+};
+
+//The next variable should not be a QVector!!!
+//We need the references to the elements to be valid, so we need this to be a QLinkedList
+//(or a QList, but make sure it allocates on the heap, which might not be always true).
+extern QLinkedList<TeacherActivityTagMinHoursDaily_item> tatmhdList;
+extern Matrix1D<QList<TeacherActivityTagMinHoursDaily_item*> > tatmhdListForTeacher;
+extern bool haveTeachersActivityTagMinHoursDaily;
+
+bool computeTeachersActivityTagMinHoursDaily(QWidget* parent);
+
+/////////////////////////////////////////////////////////////////////////
+
 extern bool fixedTimeActivity[MAX_ACTIVITIES];
 extern bool fixedSpaceActivity[MAX_ACTIVITIES];
 bool computeFixedActivities(QWidget* parent);
