@@ -3,8 +3,8 @@
 // Description: This file is part of FET
 //
 //
-// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>
-// Copyright (C) 2003 Liviu Lalescu <http://lalescu.ro/liviu/>
+// Author: Liviu Lalescu <Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>
+// Copyright (C) 2003 Liviu Lalescu <https://lalescu.ro/liviu/>
 //
 /***************************************************************************
  *                                                                         *
@@ -96,5 +96,7 @@ QString Subject::getDetailedDescriptionWithConstraints(Rules& r)
 
 int subjectsAscending(const Subject* s1, const Subject* s2)
 {
-	return s1->name < s2->name;
+//	return s1->name < s2->name;
+	//by rodolforg
+	return s1->name.localeAwareCompare(s2->name)<0;
 }
