@@ -33,7 +33,7 @@ File timetable_defs.h
 
 #include "centerwidgetonscreen.h"
 
-#if QT_VERSION < 0x050700
+#if QT_VERSION < QT_VERSION_CHECK(5,7,0)
 #include <type_traits>
 namespace std
 {
@@ -107,17 +107,22 @@ extern bool WRITE_TIMETABLES_SUBJECTS;
 extern bool WRITE_TIMETABLES_ACTIVITY_TAGS;
 extern bool WRITE_TIMETABLES_ACTIVITIES;
 
+extern bool SHOW_VIRTUAL_ROOMS_IN_TIMETABLES;
+
 extern bool SHOW_SHORTCUTS_ON_MAIN_WINDOW;
 
 extern bool SHOW_TOOLTIPS_FOR_CONSTRAINTS_WITH_TABLES;
 
 extern bool ENABLE_ACTIVITY_TAG_MAX_HOURS_DAILY;
+extern bool ENABLE_ACTIVITY_TAG_MIN_HOURS_DAILY;
 extern bool ENABLE_STUDENTS_MAX_GAPS_PER_DAY;
 
 extern bool SHOW_WARNING_FOR_NOT_PERFECT_CONSTRAINTS;
 
 extern bool SHOW_WARNING_FOR_SUBGROUPS_WITH_THE_SAME_ACTIVITIES;
 
+extern bool SHOW_WARNING_FOR_ACTIVITIES_FIXED_SPACE_VIRTUAL_REAL_ROOMS_BUT_NOT_FIXED_TIME;
+
 extern bool ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS;
 extern bool SHOW_WARNING_FOR_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS;
 
@@ -331,6 +336,7 @@ class CustomFETString{
 public:
 	static QString number(int n);
 	static QString number(double x);
+	static QString numberPlusTwoDigitsPrecision(double x);
 };
 
 double customFETStrToDouble(const QString& str, bool* ok=0);
