@@ -27,8 +27,6 @@
 
 #include "activityplanningform.h"
 
-#include "centerwidgetonscreen.h"
-
 #include <QString>
 #include <QMessageBox>
 
@@ -59,6 +57,14 @@ ActivitiesForm::ActivitiesForm(QWidget* parent, const QString& teacherName, cons
 
 	activitiesListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
 
+	QSettings settings(COMPANY, PROGRAM);
+	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
+	//restore splitter state
+	if(settings.contains(this->metaObject()->className()+QString("/splitter-state")))
+		splitter->restoreState(settings.value(this->metaObject()->className()+QString("/splitter-state")).toByteArray());
+	recursiveCheckBox->setChecked(settings.value(this->metaObject()->className()+QString("/show-related-check-box-state"), "false").toBool());
+	
 	connect(activitiesListWidget, SIGNAL(currentRowChanged(int)), this, SLOT(activityChanged()));
 	connect(addActivityPushButton, SIGNAL(clicked()), this, SLOT(addActivity()));
 	connect(removeActivityPushButton, SIGNAL(clicked()), this, SLOT(removeActivity()));
@@ -73,13 +79,6 @@ ActivitiesForm::ActivitiesForm(QWidget* parent, const QString& teacherName, cons
 	connect(helpPushButton, SIGNAL(clicked()), this, SLOT(help()));
 	connect(commentsPushButton, SIGNAL(clicked()), this, SLOT(activityComments()));
 
-	centerWidgetOnScreen(this);
-	restoreFETDialogGeometry(this);
-	//restore splitter state
-	QSettings settings(COMPANY, PROGRAM);
-	if(settings.contains(this->metaObject()->className()+QString("/splitter-state")))
-		splitter->restoreState(settings.value(this->metaObject()->className()+QString("/splitter-state")).toByteArray());
-	
 	QSize tmp1=teachersComboBox->minimumSizeHint();
 	Q_UNUSED(tmp1);
 	QSize tmp2=studentsComboBox->minimumSizeHint();
@@ -119,7 +118,8 @@ ActivitiesForm::ActivitiesForm(QWidget* parent, const QString& teacherName, cons
 	}
 	activityTagsComboBox->setCurrentIndex(ciat);
 
-	studentsComboBox->addItem("");
+	int cist=populateStudentsComboBox(studentsComboBox, studentsSetName, true);
+	/*studentsComboBox->addItem("");
 	int cist=0;
 	int currentID=0;
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
@@ -142,8 +142,37 @@ ActivitiesForm::ActivitiesForm(QWidget* parent, const QString& teacherName, cons
 					cist=currentID;
 			}
 		}
+	}*/
+	if(studentsSetName==""){
+		assert(cist==0);
+		studentsComboBox->setCurrentIndex(0);
+
+		showedStudents.clear();
+		showedStudents.insert("");
+	
+		filterChanged();
 	}
-	studentsComboBox->setCurrentIndex(cist);
+	else{
+		assert(cist!=0);
+
+		if(cist==-1){
+			studentsComboBox->setCurrentIndex(0);
+
+			showWarningForInvisibleSubgroupActivity(parent, studentsSetName);
+
+			showedStudents.clear();
+			showedStudents.insert("");
+	
+			filterChanged();
+		}
+		else{
+			studentsComboBox->setCurrentIndex(cist);
+
+			this->studentsFilterChanged();
+		}
+	}
+
+	/*studentsComboBox->setCurrentIndex(cist);
 	
 	if(studentsSetName!=""){
 		if(cist==0){
@@ -163,7 +192,7 @@ ActivitiesForm::ActivitiesForm(QWidget* parent, const QString& teacherName, cons
 		showedStudents.insert("");
 	
 		filterChanged();
-	}
+	}*/
 }
 
 ActivitiesForm::~ActivitiesForm()
@@ -172,6 +201,8 @@ ActivitiesForm::~ActivitiesForm()
 	//save splitter state
 	QSettings settings(COMPANY, PROGRAM);
 	settings.setValue(this->metaObject()->className()+QString("/splitter-state"), splitter->saveState());
+
+	settings.setValue(this->metaObject()->className()+QString("/show-related-check-box-state"), recursiveCheckBox->isChecked());
 }
 
 bool ActivitiesForm::filterOk(Activity* act)
@@ -241,16 +272,16 @@ void ActivitiesForm::studentsFilterChanged()
 			if(set->type==STUDENTS_YEAR){
 				StudentsYear* year=(StudentsYear*)set;
 				showedStudents.insert(year->name);
-				foreach(StudentsGroup* group, year->groupsList){
+				for(StudentsGroup* group : qAsConst(year->groupsList)){
 					showedStudents.insert(group->name);
-					foreach(StudentsSubgroup* subgroup, group->subgroupsList)
+					for(StudentsSubgroup* subgroup : qAsConst(group->subgroupsList))
 						showedStudents.insert(subgroup->name);
 				}
 			}
 			else if(set->type==STUDENTS_GROUP){
 				StudentsGroup* group=(StudentsGroup*) set;
 				showedStudents.insert(group->name);
-				foreach(StudentsSubgroup* subgroup, group->subgroupsList)
+				for(StudentsSubgroup* subgroup : qAsConst(group->subgroupsList))
 					showedStudents.insert(subgroup->name);
 			}
 			else if(set->type==STUDENTS_SUBGROUP){
@@ -262,12 +293,12 @@ void ActivitiesForm::studentsFilterChanged()
 				
 			//up
 			QString crt=studentsComboBox->currentText();
-			foreach(StudentsYear* year, gt.rules.yearsList){
-				foreach(StudentsGroup* group, year->groupsList){
+			for(StudentsYear* year : qAsConst(gt.rules.yearsList)){
+				for(StudentsGroup* group : qAsConst(year->groupsList)){
 					if(group->name==crt){
 						showedStudents.insert(year->name);
 					}
-					foreach(StudentsSubgroup* subgroup, group->subgroupsList){
+					for(StudentsSubgroup* subgroup : qAsConst(group->subgroupsList)){
 						if(subgroup->name==crt){
 							showedStudents.insert(year->name);
 							showedStudents.insert(group->name);
