@@ -39,6 +39,10 @@
 extern const QString COMPANY;
 extern const QString PROGRAM;
 
+extern bool students_schedule_ready;
+extern bool rooms_schedule_ready;
+extern bool teachers_schedule_ready;
+
 ActivityTagsForm::ActivityTagsForm(QWidget* parent): QDialog(parent)
 {
 	setupUi(this);
@@ -211,6 +215,10 @@ void ActivityTagsForm::moveActivityTagUp()
 	
 	gt.rules.internalStructureComputed=false;
 	setRulesModifiedAndOtherThings(&gt.rules);
+
+	teachers_schedule_ready=false;
+	students_schedule_ready=false;
+	rooms_schedule_ready=false;
 	
 	activityTagsListWidget->item(i)->setText(s2);
 	activityTagsListWidget->item(i-1)->setText(s1);
@@ -241,6 +249,10 @@ void ActivityTagsForm::moveActivityTagDown()
 	gt.rules.internalStructureComputed=false;
 	setRulesModifiedAndOtherThings(&gt.rules);
 	
+	teachers_schedule_ready=false;
+	students_schedule_ready=false;
+	rooms_schedule_ready=false;
+
 	activityTagsListWidget->item(i)->setText(s2);
 	activityTagsListWidget->item(i+1)->setText(s1);
 	
