@@ -84,7 +84,8 @@ AddConstraintActivitiesOccupyMaxDifferentRoomsForm::AddConstraintActivitiesOccup
 	}
 	activityTagsComboBox->setCurrentIndex(0);
 
-	studentsComboBox->addItem("");
+	populateStudentsComboBox(studentsComboBox, QString(""), true);
+	/*studentsComboBox->addItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -96,7 +97,7 @@ AddConstraintActivitiesOccupyMaxDifferentRoomsForm::AddConstraintActivitiesOccup
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 	studentsComboBox->setCurrentIndex(0);
 
 	selectedActivitiesListWidget->clear();
