@@ -51,7 +51,7 @@ AddConstraintStudentsActivityTagMaxHoursDailyForm::~AddConstraintStudentsActivit
 
 void AddConstraintStudentsActivityTagMaxHoursDailyForm::updateActivityTagsComboBox()
 {
-	foreach(ActivityTag* at, gt.rules.activityTagsList)
+	for(ActivityTag* at : qAsConst(gt.rules.activityTagsList))
 		activityTagsComboBox->addItem(at->name);
 
 	constraintChanged();
