@@ -55,7 +55,8 @@ AddConstraintStudentsSetActivityTagMaxHoursDailyForm::~AddConstraintStudentsSetA
 
 void AddConstraintStudentsSetActivityTagMaxHoursDailyForm::updateStudentsSetComboBox()
 {
-	studentsComboBox->clear();	
+	populateStudentsComboBox(studentsComboBox);
+	/*studentsComboBox->clear();
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -67,14 +68,14 @@ void AddConstraintStudentsSetActivityTagMaxHoursDailyForm::updateStudentsSetComb
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 
 	constraintChanged();
 }
 
 void AddConstraintStudentsSetActivityTagMaxHoursDailyForm::updateActivityTagsComboBox()
 {
-	foreach(ActivityTag* at, gt.rules.activityTagsList)
+	for(ActivityTag* at : qAsConst(gt.rules.activityTagsList))
 		activityTagsComboBox->addItem(at->name);
 
 	constraintChanged();
