@@ -53,7 +53,8 @@ AddConstraintStudentsSetMaxSpanPerDayForm::~AddConstraintStudentsSetMaxSpanPerDa
 
 void AddConstraintStudentsSetMaxSpanPerDayForm::updateStudentsSetComboBox()
 {
-	studentsComboBox->clear();
+	populateStudentsComboBox(studentsComboBox);
+	/*studentsComboBox->clear();
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -65,7 +66,7 @@ void AddConstraintStudentsSetMaxSpanPerDayForm::updateStudentsSetComboBox()
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 
 	constraintChanged();
 }
