@@ -40,7 +40,7 @@ AddConstraintTeachersActivityTagMaxHoursContinuouslyForm::AddConstraintTeachersA
 	updateMaxHoursSpinBox();
 
 	activityTagsComboBox->clear();
-	foreach(ActivityTag* at, gt.rules.activityTagsList)
+	for(ActivityTag* at : qAsConst(gt.rules.activityTagsList))
 		activityTagsComboBox->addItem(at->name);
 
 	constraintChanged();
