@@ -79,7 +79,8 @@ AddConstraintThreeActivitiesGroupedForm::AddConstraintThreeActivitiesGroupedForm
 	}
 	activityTagsComboBox->setCurrentIndex(0);
 
-	studentsComboBox->addItem("");
+	populateStudentsComboBox(studentsComboBox, QString(""), true);
+	/*studentsComboBox->addItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -91,7 +92,7 @@ AddConstraintThreeActivitiesGroupedForm::AddConstraintThreeActivitiesGroupedForm
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 	studentsComboBox->setCurrentIndex(0);
 
 	updateActivitiesComboBox();
