@@ -84,7 +84,8 @@ ConstraintActivitiesSameStartingDayForm::ConstraintActivitiesSameStartingDayForm
 	}
 	activityTagsComboBox->setCurrentIndex(0);
 
-	studentsComboBox->addItem("");
+	populateStudentsComboBox(studentsComboBox, QString(""), true);
+	/*studentsComboBox->addItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -96,7 +97,7 @@ ConstraintActivitiesSameStartingDayForm::ConstraintActivitiesSameStartingDayForm
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 	studentsComboBox->setCurrentIndex(0);
 ///////////////
 
@@ -151,7 +152,7 @@ bool ConstraintActivitiesSameStartingDayForm::filterOk(TimeConstraint* ctr)
 	
 		int id=c->activitiesId[i];
 		Activity* act=NULL;
-		foreach(Activity* a, gt.rules.activitiesList)
+		for(Activity* a : qAsConst(gt.rules.activitiesList))
 			if(a->id==id)
 				act=a;
 		
