@@ -82,7 +82,8 @@ ConstraintActivityPreferredRoomsForm::ConstraintActivityPreferredRoomsForm(QWidg
 	}
 	activityTagsComboBox->setCurrentIndex(0);
 
-	studentsComboBox->addItem("");
+	populateStudentsComboBox(studentsComboBox, QString(""), true);
+	/*studentsComboBox->addItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -94,7 +95,7 @@ ConstraintActivityPreferredRoomsForm::ConstraintActivityPreferredRoomsForm(QWidg
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 	studentsComboBox->setCurrentIndex(0);
 ///////////////
 
@@ -140,7 +141,7 @@ bool ConstraintActivityPreferredRoomsForm::filterOk(SpaceConstraint* ctr)
 	
 	int id=c->activityId;
 	Activity* act=NULL;
-	foreach(Activity* a, gt.rules.activitiesList)
+	for(Activity* a : qAsConst(gt.rules.activitiesList))
 		if(a->id==id)
 			act=a;
 
