@@ -56,7 +56,7 @@ ConstraintStudentsActivityTagMaxHoursDailyForm::ConstraintStudentsActivityTagMax
 	
 	activityTagsComboBox->clear();
 	activityTagsComboBox->addItem("");
-	foreach(ActivityTag* at, gt.rules.activityTagsList)
+	for(ActivityTag* at : qAsConst(gt.rules.activityTagsList))
 		activityTagsComboBox->addItem(at->name);
 
 	this->filterChanged();
