@@ -54,7 +54,8 @@ ConstraintStudentsSetMinHoursDailyForm::ConstraintStudentsSetMinHoursDailyForm(Q
 	QSize tmp2=studentsComboBox->minimumSizeHint();
 	Q_UNUSED(tmp2);
 
-	studentsComboBox->addItem("");
+	populateStudentsComboBox(studentsComboBox, QString(""), true);
+	/*studentsComboBox->addItem("");
 
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
@@ -67,7 +68,7 @@ ConstraintStudentsSetMinHoursDailyForm::ConstraintStudentsSetMinHoursDailyForm(Q
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 
 	this->filterChanged();
 }
