@@ -62,7 +62,7 @@ ConstraintTeacherActivityTagMaxHoursContinuouslyForm::ConstraintTeacherActivityT
 	
 	activityTagsComboBox->clear();
 	activityTagsComboBox->addItem("");
-	foreach(ActivityTag* at, gt.rules.activityTagsList)
+	for(ActivityTag* at : qAsConst(gt.rules.activityTagsList))
 		activityTagsComboBox->addItem(at->name);
 
 	this->filterChanged();
