@@ -56,11 +56,11 @@ ConstraintTeacherHomeRoomsForm::ConstraintTeacherHomeRoomsForm(QWidget* parent):
 	Q_UNUSED(tmp5);
 	
 	teachersComboBox->addItem("");
-	foreach(Teacher* tch, gt.rules.teachersList)
+	for(Teacher* tch : qAsConst(gt.rules.teachersList))
 		teachersComboBox->addItem(tch->name);
-					
+	
 	roomsComboBox->addItem("");
-	foreach(Room* rm, gt.rules.roomsList)
+	for(Room* rm : qAsConst(gt.rules.roomsList))
 		roomsComboBox->addItem(rm->name);
 
 	this->refreshConstraintsListWidget();
