@@ -25,6 +25,8 @@ File fet.cpp - this is where the program FET starts
 
 #include "messageboxes.h"
 
+#include "rules.h"
+
 #ifndef FET_COMMAND_LINE
 #include <QMessageBox>
 
@@ -53,6 +55,7 @@ static QSet<QString> languagesSet;
 #include "fetmainform.h"
 
 #include "helpaboutform.h"
+#include "helpaboutlibrariesform.h"
 #include "helpfaqform.h"
 #include "helptipsform.h"
 #include "helpinstructionsform.h"
@@ -87,6 +90,7 @@ static QSet<QString> languagesSet;
 
 #ifdef FET_COMMAND_LINE
 #include <csignal>
+#include <QtGlobal>
 #endif
 
 #include <iostream>
@@ -147,6 +151,7 @@ qint16 rooms_timetable_weekly[MAX_ROOMS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY];*
 Matrix3D<int> teachers_timetable_weekly;
 Matrix3D<int> students_timetable_weekly;
 Matrix3D<int> rooms_timetable_weekly;
+Matrix3D<QList<int> > virtual_rooms_timetable_weekly;
 //QList<qint16> teachers_free_periods_timetable_weekly[TEACHERS_FREE_PERIODS_N_CATEGORIES][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY];
 Matrix3D<QList<int> > teachers_free_periods_timetable_weekly;
 
@@ -226,6 +231,8 @@ void usage(QTextStream* out, const QString& error)
 		"[--warnifusingstudentsminhoursdailywithallowemptydays=p] [--warnifusinggroupactivitiesininitialorder=g] [--warnsubgroupswiththesameactivities=ssa]\n"
 		"[--printdetailedtimetables=pdt] [--printdetailedteachersfreeperiodstimetables=pdtfp] "
 		"[--exportcsv=ecsv] [--overwritecsv=ocsv] [--firstlineisheadingcsv=flhcsv] [--quotescsv=qcsv] [--fieldseparatorcsv=fscsv] "
+		"[--showvirtualrooms=svr] "
+		"[--warnifusingactivitiesnotfixedtimefixedspacevirtualroomsrealrooms=wanftfs] "
 		"[--verbose=r]\",\n"
 		"where:\nx is the input file, for instance \"data.fet\"\n"
 		"d is the path to results directory, without trailing slash or backslash (default is current working path). "
@@ -265,11 +272,14 @@ void usage(QTextStream* out, const QString& error)
 		"doublequotes.\n"
 		"fscsv is one value from the set [comma|semicolon|verticalbar] (write a single value from these three exactly as it is written here). The default value is "
 		"comma.\n"
+		"svr is either true or false, represents whether you want to show virtual rooms in the timetables (default false).\n"
+		"wanftfs is either true or false, represents whether you want the program to issue a warning if you are using activites which are not fixed in time, "
+		"but are fixed in space in a virtual room, specifying also the real rooms (which is not recommended) (default true).\n"
 		"r is either true or false, represents whether you want additional generation messages and other messages to be shown on the command line (default false).\n"
 		"Alternatively, you can run \"fet-cl --version [--outputdir=d]\" to get the current FET version, "
 		"where\nd is the path to results directory, without trailing slash or backslash (default is current working path). "
 		"Make sure you have write permissions there.\n"
-		"(If you specify the \"--version argument\", FET just prints version number on the command line prompt and in the output directory and exits.)\n"
+		"(If you specify the \"--version\" argument, FET just prints version number on the command line prompt and in the output directory and exits.)\n"
 		"\n"
 		"You can ask the FET command line process to stop the timetable generation, by sending it the SIGTERM (or SIGBREAK, on Windows) signal. "
 		"FET will then write the current timetable and the highest stage timetable and exit. "
@@ -395,14 +405,18 @@ void readSimulationParameters()
 /////////
 
 	ENABLE_ACTIVITY_TAG_MAX_HOURS_DAILY=newSettings.value("enable-activity-tag-max-hours-daily", "false").toBool();
+	ENABLE_ACTIVITY_TAG_MIN_HOURS_DAILY=newSettings.value("enable-activity-tag-min-hours-daily", "false").toBool();
 	ENABLE_STUDENTS_MAX_GAPS_PER_DAY=newSettings.value("enable-students-max-gaps-per-day", "false").toBool();
 	SHOW_WARNING_FOR_NOT_PERFECT_CONSTRAINTS=newSettings.value("warn-if-using-not-perfect-constraints", "true").toBool();
 	SHOW_WARNING_FOR_SUBGROUPS_WITH_THE_SAME_ACTIVITIES=newSettings.value("warn-subgroups-with-the-same-activities", "true").toBool();
+	SHOW_WARNING_FOR_ACTIVITIES_FIXED_SPACE_VIRTUAL_REAL_ROOMS_BUT_NOT_FIXED_TIME=newSettings.value("warn-activities-not-fixed-time-fixed-space-virtual-real", "true").toBool();
 	ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS=newSettings.value("enable-students-min-hours-daily-with-allow-empty-days", "false").toBool();
 	SHOW_WARNING_FOR_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS=newSettings.value("warn-if-using-students-min-hours-daily-with-allow-empty-days", "true").toBool();
 	
 	ENABLE_GROUP_ACTIVITIES_IN_INITIAL_ORDER=newSettings.value("enable-group-activities-in-initial-order", "false").toBool();
 	SHOW_WARNING_FOR_GROUP_ACTIVITIES_IN_INITIAL_ORDER=newSettings.value("warn-if-using-group-activities-in-initial-order", "true").toBool();
+
+	SHOW_VIRTUAL_ROOMS_IN_TIMETABLES=newSettings.value("show-virtual-rooms-in-timetables", "false").toBool();
 	
 	//main form
 	QRect rect=newSettings.value("FetMainForm/geometry", QRect(0,0,0,0)).toRect();
@@ -472,15 +486,19 @@ void writeSimulationParameters()
 ///////////
 
 	settings.setValue("enable-activity-tag-max-hours-daily", ENABLE_ACTIVITY_TAG_MAX_HOURS_DAILY);
+	settings.setValue("enable-activity-tag-min-hours-daily", ENABLE_ACTIVITY_TAG_MIN_HOURS_DAILY);
 	settings.setValue("enable-students-max-gaps-per-day", ENABLE_STUDENTS_MAX_GAPS_PER_DAY);
 	settings.setValue("warn-if-using-not-perfect-constraints", SHOW_WARNING_FOR_NOT_PERFECT_CONSTRAINTS);
 	settings.setValue("warn-subgroups-with-the-same-activities", SHOW_WARNING_FOR_SUBGROUPS_WITH_THE_SAME_ACTIVITIES);
+	settings.setValue("warn-activities-not-fixed-time-fixed-space-virtual-real", SHOW_WARNING_FOR_ACTIVITIES_FIXED_SPACE_VIRTUAL_REAL_ROOMS_BUT_NOT_FIXED_TIME);
 	settings.setValue("enable-students-min-hours-daily-with-allow-empty-days", ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS);
 	settings.setValue("warn-if-using-students-min-hours-daily-with-allow-empty-days", SHOW_WARNING_FOR_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS);
 
 	settings.setValue("enable-group-activities-in-initial-order", ENABLE_GROUP_ACTIVITIES_IN_INITIAL_ORDER);
 	settings.setValue("warn-if-using-group-activities-in-initial-order", SHOW_WARNING_FOR_GROUP_ACTIVITIES_IN_INITIAL_ORDER);
 
+	settings.setValue("show-virtual-rooms-in-timetables", SHOW_VIRTUAL_ROOMS_IN_TIMETABLES);
+
 	//main form
 	settings.setValue("FetMainForm/geometry", mainFormSettingsRect);
 	//settings.setValue("FetMainForm/shortcuts-tab-position", MAIN_FORM_SHORTCUTS_TAB_POSITION);
@@ -641,6 +659,12 @@ void setLanguage(QCoreApplication& qapplication, QWidget* parent)
 				continue;
 			}
 
+			HelpAboutLibrariesForm* aboutlibsf=qobject_cast<HelpAboutLibrariesForm*>(wi);
+			if(aboutlibsf!=NULL){
+				aboutlibsf->retranslateUi(aboutlibsf);
+				continue;
+			}
+
 			HelpFaqForm* faqf=qobject_cast<HelpFaqForm*>(wi);
 			if(faqf!=NULL){
 				faqf->retranslateUi(faqf);
@@ -923,10 +947,14 @@ int main(int argc, char **argv)
 		
 		SHOW_WARNING_FOR_SUBGROUPS_WITH_THE_SAME_ACTIVITIES=true;
 		
+		SHOW_WARNING_FOR_ACTIVITIES_FIXED_SPACE_VIRTUAL_REAL_ROOMS_BUT_NOT_FIXED_TIME=true;
+		
 		SHOW_WARNING_FOR_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS=true;
 		
 		SHOW_WARNING_FOR_GROUP_ACTIVITIES_IN_INITIAL_ORDER=true;
 		
+		SHOW_VIRTUAL_ROOMS_IN_TIMETABLES=false;
+		
 		EXPORT_CSV=false;
 		EXPORT_ALLOW_OVERWRITE=false;
 		EXPORT_FIRST_LINE_IS_HEADING=true;
@@ -999,6 +1027,10 @@ int main(int argc, char **argv)
 				if(s.right(5)=="false")
 					SHOW_WARNING_FOR_SUBGROUPS_WITH_THE_SAME_ACTIVITIES=false;
 			}
+			else if(s.left(67)=="--warnifusingactivitiesnotfixedtimefixedspacevirtualroomsrealrooms="){
+				if(s.right(5)=="false")
+					SHOW_WARNING_FOR_ACTIVITIES_FIXED_SPACE_VIRTUAL_REAL_ROOMS_BUT_NOT_FIXED_TIME=false;
+			}
 			else if(s.left(43)=="--warnifusinggroupactivitiesininitialorder="){
 				if(s.right(5)=="false")
 					SHOW_WARNING_FOR_GROUP_ACTIVITIES_IN_INITIAL_ORDER=false;
@@ -1007,6 +1039,10 @@ int main(int argc, char **argv)
 				if(s.right(5)=="false")
 					SHOW_WARNING_FOR_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS=false;
 			}
+			else if(s.left(19)=="--showvirtualrooms="){
+				if(s.right(4)=="true")
+					SHOW_VIRTUAL_ROOMS_IN_TIMETABLES=true;
+			}
 			else if(s.left(10)=="--verbose="){
 				if(s.right(4)=="true")
 					VERBOSE=true;
@@ -1159,6 +1195,16 @@ int main(int argc, char **argv)
 		QTextStream out(&logFile);
 		///////
 		
+		//Cleanup the previous unsuccessful generation, if any. No need to remove the other files, they are overwritten.
+		QFile oldDifficultActivitiesFile(logsDir+"difficult_activities.txt");
+		if(oldDifficultActivitiesFile.exists()){
+			bool t=oldDifficultActivitiesFile.remove();
+			if(!t){
+				out<<"Cannot remove the old existing file "<<qPrintable(logsDir)<<"difficult_activities.txt"<<endl;
+				cout<<"Cannot remove the old existing file "<<qPrintable(logsDir)<<"difficult_activities.txt"<<endl;
+			}
+		}
+		
 		setLanguage(qCoreApplication, NULL);
 		
 		if(showVersion){
@@ -1170,17 +1216,23 @@ int main(int argc, char **argv)
 			QString sTime=loc.toString(dat, QLocale::ShortFormat)+" "+loc.toString(tim, QLocale::ShortFormat);
 			out<<"FET command line request for version started on "<<qPrintable(sTime)<<endl<<endl;
 	
-			//QString qv=qVersion();
 			out<<"FET version "<<qPrintable(FET_VERSION)<<endl;
 			out<<"Free timetabling software, licensed under the GNU Affero General Public License version 3 or later"<<endl;
-			out<<"Copyright (C) 2002-2019 Liviu Lalescu, Volker Dirr"<<endl;
+			out<<"Copyright (C) 2002-2020 Liviu Lalescu, Volker Dirr"<<endl;
 			out<<"Homepage: https://lalescu.ro/liviu/fet/"<<endl;
-			//out<<" (Using Qt version "<<qPrintable(qv)<<")"<<endl;
+			out<<"This program uses Qt version "<<qVersion()<<", Copyright (C) The Qt Company Ltd and other contributors."<<endl;
+			out<<"Depending on the platform and compiler, this program may use libraries from:"<<endl;
+			out<<"  gcc, Copyright (C) Free Software Foundation, Inc."<<endl;
+			out<<"  mingw-w64, Copyright (c) by the mingw-w64 project"<<endl;
+
 			cout<<"FET version "<<qPrintable(FET_VERSION)<<endl;
 			cout<<"Free timetabling software, licensed under the GNU Affero General Public License version 3 or later"<<endl;
-			cout<<"Copyright (C) 2002-2019 Liviu Lalescu, Volker Dirr"<<endl;
+			cout<<"Copyright (C) 2002-2020 Liviu Lalescu, Volker Dirr"<<endl;
 			cout<<"Homepage: https://lalescu.ro/liviu/fet/"<<endl;
-			//cout<<" (Using Qt version "<<qPrintable(qv)<<")"<<endl;
+			cout<<"This program uses Qt version "<<qVersion()<<", Copyright (C) The Qt Company Ltd and other contributors."<<endl;
+			cout<<"Depending on the platform and compiler, this program may use libraries from:"<<endl;
+			cout<<"  gcc, Copyright (C) Free Software Foundation, Inc."<<endl;
+			cout<<"  mingw-w64, Copyright (c) by the mingw-w64 project"<<endl;
 
 			if(unrecognizedOptions.count()>0){
 				out<<endl;
@@ -1304,8 +1356,22 @@ int main(int argc, char **argv)
 	
 		bool t=gt.rules.read(NULL, filename, true, initialDir);
 		if(!t){
-			cout<<"fet: cannot read input file (not existing or in use) - aborting"<<endl;
-			out<<"Cannot read input file (not existing or in use) - aborting"<<endl;
+			cout<<"fet-cl: cannot read input file (not existing, in use, or incorrect file) - aborting"<<endl;
+			out<<"Cannot read input file (not existing, in use, or incorrect file) - aborting"<<endl;
+			logFile.close();
+			return 1;
+		}
+		
+		//2019-09-21
+		int count=0;
+		for(int i=0; i<gt.rules.activitiesList.size(); i++){
+			Activity* act=gt.rules.activitiesList[i];
+			if(act->active)
+				count++;
+		}
+		if(count<1){
+			cout<<"Please input at least one active activity before generating"<<endl;
+			out<<"Please input at least one active activity before generating"<<endl;
 			logFile.close();
 			return 1;
 		}
@@ -1363,7 +1429,7 @@ int main(int argc, char **argv)
 			Solution& cc=gen.c;
 
 			//needed to find the conflicts strings
-			QString tmp;
+			FakeString tmp;
 			cc.fitness(gt.rules, &tmp);
 
 			TimetableExport::getStudentsTimetable(cc);
@@ -1422,7 +1488,7 @@ int main(int argc, char **argv)
 			Solution& ch=highestStageSolution;
 
 			//needed to find the conflicts strings
-			QString tmp2;
+			FakeString tmp2;
 			ch.fitness(gt.rules, &tmp2);
 
 			TimetableExport::getStudentsTimetable(ch);
@@ -1468,7 +1534,7 @@ int main(int argc, char **argv)
 			Solution& cc=gen.c;
 
 			//needed to find the conflicts strings
-			QString tmp;
+			FakeString tmp;
 			cc.fitness(gt.rules, &tmp);
 
 			TimetableExport::getStudentsTimetable(cc);
@@ -1546,7 +1612,7 @@ int main(int argc, char **argv)
 			Solution& ch=highestStageSolution;
 
 			//needed to find the conflicts strings
-			QString tmp2;
+			FakeString tmp2;
 			ch.fitness(gt.rules, &tmp2);
 
 			TimetableExport::getStudentsTimetable(ch);
@@ -1582,7 +1648,7 @@ int main(int argc, char **argv)
 			Solution& c=gen.c;
 
 			//needed to find the conflicts strings
-			QString tmp;
+			FakeString tmp;
 			c.fitness(gt.rules, &tmp);
 			
 			TimetableExport::getStudentsTimetable(c);
