@@ -39,6 +39,10 @@
 extern const QString COMPANY;
 extern const QString PROGRAM;
 
+extern bool students_schedule_ready;
+extern bool rooms_schedule_ready;
+extern bool teachers_schedule_ready;
+
 GroupsForm::GroupsForm(QWidget* parent): QDialog(parent)
 {
 	setupUi(this);
@@ -137,8 +141,8 @@ void GroupsForm::removeGroup()
 
 	QList<QString> yearsContainingGroup_List;
 	//QSet<QString> yearsContainingGroup_Set;
-	foreach(StudentsYear* year, gt.rules.yearsList)
-		foreach(StudentsGroup* group, year->groupsList)
+	for(StudentsYear* year : qAsConst(gt.rules.yearsList))
+		for(StudentsGroup* group : qAsConst(year->groupsList))
 			if(group->name==groupName)
 				yearsContainingGroup_List.append(year->name);
 			
@@ -151,7 +155,7 @@ void GroupsForm::removeGroup()
 		s=tr("This group exists in more places, listed below. It will only be removed from the current year,"
 		 " and the related activities and constraints will not be removed. Do you want to continue?");
 		s+="\n";
-		foreach(QString str, yearsContainingGroup_List)
+		for(const QString& str : qAsConst(yearsContainingGroup_List))
 			s+=QString("\n")+str;
 	}
 	
@@ -208,8 +212,8 @@ void GroupsForm::purgeGroup()
 
 	QList<QString> yearsContainingGroup_List;
 	//QSet<QString> yearsContainingGroup_Set;
-	foreach(StudentsYear* year, gt.rules.yearsList)
-		foreach(StudentsGroup* group, year->groupsList)
+	for(StudentsYear* year : qAsConst(gt.rules.yearsList))
+		for(StudentsGroup* group : qAsConst(year->groupsList))
 			if(group->name==groupName)
 				yearsContainingGroup_List.append(year->name);
 			
@@ -222,7 +226,7 @@ void GroupsForm::purgeGroup()
 		s=tr("This group exists in more places, listed below. It will be removed from all these places."
 		 " All the related activities and constraints will be removed. Do you want to continue?");
 		s+="\n";
-		foreach(QString str, yearsContainingGroup_List)
+		for(const QString& str : qAsConst(yearsContainingGroup_List))
 			s+=QString("\n")+str;
 	}
 	
@@ -316,6 +320,10 @@ void GroupsForm::moveGroupUp()
 	gt.rules.internalStructureComputed=false;
 	setRulesModifiedAndOtherThings(&gt.rules);
 	
+	teachers_schedule_ready=false;
+	students_schedule_ready=false;
+	rooms_schedule_ready=false;
+
 	groupsListWidget->item(i)->setText(s2);
 	groupsListWidget->item(i-1)->setText(s1);
 	
@@ -349,6 +357,10 @@ void GroupsForm::moveGroupDown()
 	gt.rules.internalStructureComputed=false;
 	setRulesModifiedAndOtherThings(&gt.rules);
 	
+	teachers_schedule_ready=false;
+	students_schedule_ready=false;
+	rooms_schedule_ready=false;
+
 	groupsListWidget->item(i)->setText(s2);
 	groupsListWidget->item(i+1)->setText(s1);
 	
