@@ -75,10 +75,10 @@ HelpAboutForm::HelpAboutForm(QWidget* parent): QDialog(parent)
 	about+=tr("FET is free software for automatically scheduling the timetable of a school, high-school or university.");
 	about+="<br /><br />";
 	about+=tr("Copyright (C) %1-%2 %3.", "%1 is the year of the first FET release, %2 is the current release year, %3 are the FET authors")
-	 .arg(2002).arg(2019).arg("Liviu Lalescu, Volker Dirr");
+	 .arg(2002).arg(2020).arg("Liviu Lalescu, Volker Dirr");
 	about+="<br /><br />";
 	about+=tr("Version: %1 (%2 %3).", "%1 is the current FET version, %2 is the current release month, %3 is the current release year").arg(FET_VERSION)
-	 .arg(QCoreApplication::translate("MonthsNames", "July")).arg(2019);
+	 .arg(QCoreApplication::translate("MonthsNames", "January")).arg(2020);
 	about+="<br /><br />";
 	about+=tr("Licensed under the GNU Affero General Public License version 3 or later.");
 	about+="<br /><br />";
@@ -431,7 +431,7 @@ HelpAboutForm::HelpAboutForm(QWidget* parent): QDialog(parent)
 	thanksTo+=QString("<br />");
 	thanksTo+=QString("Patrick Fox");
 	thanksTo+=QString("<br />");
-	thanksTo+=QString("Andres Chandia");
+	thanksTo+=QString::fromUtf8("Andrés Chandía");
 	thanksTo+=QString("<br />");
 	thanksTo+=QString("Zoran Zdravkovski");
 	thanksTo+=QString("<br />");
@@ -929,6 +929,32 @@ HelpAboutForm::HelpAboutForm(QWidget* parent): QDialog(parent)
 	thanksTo+=QString("<br />");
 	thanksTo+=QString("Henrique Belo");
 	thanksTo+=QString("<br />");
+	thanksTo+=QString("Luca");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("totera");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("astigol");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("dimzev");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Zafar Allah Askar");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Lysso");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString::fromUtf8("Marco Diego Aurélio Mesquita");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("forstera");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("otman hashem");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Ahmed El Hawary");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Abdellah Sabri");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("khatou1973");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("nachrach111");
+	thanksTo+=QString("<br />");
 
 	thanksToTextBrowser->setHtml(thanksTo);
 }
