@@ -46,7 +46,7 @@ void HelpFaqForm::setText()
 	
 	s+=tr("Frequently asked questions.");
 	s+="\n\n";
-	s+=tr("Last modified on %1.").arg(tr("24 July 2019"));
+	s+=tr("Last modified on %1.").arg(tr("21 November 2019"));
 	
 	s+="\n\n";
 	s+="--------------------";
@@ -710,6 +710,8 @@ void HelpFaqForm::setText()
 	s+="--------------------";
 	s+="\n\n";
 
+	s+=tr("(This FAQ entry applies also to the constraints of type activity tag min hours daily:)");
+	s+=" ";
 	s+=tr("Question 1/25 September 2009: An observation for constraint teacher(s) or students (set) activity tag max hours daily:\n\n"
 		"This constraint is implemented correctly and is working good, but it is not perfect, which means that in unusual, extreme cases the "
 		"time needed to generate a timetable might be longer or much longer than really necessary. You should give FET a hand in these extreme "
@@ -762,6 +764,8 @@ void HelpFaqForm::setText()
 	s+="--------------------";
 	s+="\n\n";
 	
+	s+=tr("(This FAQ entry applies also to the constraints of type activity tag min hours daily:)");
+	s+=" ";
 	s+=tr("Q: Why the constraints activity tag max hours daily and students max gaps per day are disabled in the FET menu?");
 	s+="\n\n";
 	s+=tr("A: These 6 constraints (4 for activity tag and 2 for students max gaps per day) are the only ones which are not perfectly optimized"
@@ -882,8 +886,10 @@ void HelpFaqForm::setText()
 
 	s+=tr("Q: I would like to specify that a teacher should have activities in certain time slots, no matter which activities.");
 	s+="\n\n";
-	s+=tr("A: Please use constraint activities occupy max time slots from selection (the exact menu entry is 'A set of activities occupies max"
-	 " time slots from selection'. See that constraint's Help button for more details.");
+	s+=tr("A: You can use a constraint of type activities occupy min time slots from selection or use in an inverted way a constraint of type activities"
+	 " occupy max time slots from selection (the exact menu entries are 'A set of activities occupies min/max time slots from selection')."
+	 " It is not known exactly if the inverted constraint with 'max' is more efficient than the direct constraint with 'min'."
+	 " Press these constraints' Help buttons for more details.");
 
 	s+="\n\n";
 	s+="--------------------";
@@ -1061,5 +1067,32 @@ void HelpFaqForm::setText()
 	s+="\n\n";
 	s+=tr("The uses of this constraint might be wider.");
 
+	s+="\n\n";
+	s+="--------------------";
+	s+="\n\n";
+	
+	s+=tr("Q: How can I say that an activity should take place in more rooms?");
+	s+="\n\n";
+	s+=tr("A:", "Answer");
+	s+=" ";
+	s+=tr("You could use virtual rooms for this. Read the Help on those dialogs (the Rooms dialog and the Make/edit virtual room dialog)."
+		" In short, you need to add a virtual room with n sets of real rooms, where n is the number of rooms you want the activity to occupy.");
+	s+="\n\n";
+	s+=tr("There is also another possible solution, to add dummy activities and constrain them to start at the same time as the real activity.");
+
+	s+="\n\n";
+	s+="--------------------";
+	s+="\n\n";
+	
+	s+=tr("Q: What is the use of virtual rooms?");
+	s+="\n\n";
+	s+=tr("A:", "Answer");
+	s+=" ";
+	s+=tr("Virtual rooms were suggested by the user %1 on the FET forum (%2). They can be used to make an activity occupy more rooms, or even to let FET"
+		" choose between a large room for this activity or more smaller rooms (if you set the preferred rooms for this activity the"
+		" real large room or a virtual room representing the more smaller rooms)."
+		" Please read the Help on the virtual rooms dialogs (the Rooms dialog and the Make/edit virtual room dialog).").arg("math")
+		.arg("https://lalescu.ro/liviu/fet/forum/index.php?topic=4249.0");
+
 	plainTextEdit->setPlainText(s);
 }
