@@ -100,7 +100,8 @@ ModifyConstraintActivitiesSameStartingTimeForm::ModifyConstraintActivitiesSameSt
 	}
 	activityTagsComboBox->setCurrentIndex(0);
 
-	studentsComboBox->addItem("");
+	populateStudentsComboBox(studentsComboBox, QString(""), true);
+	/*studentsComboBox->addItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -112,7 +113,7 @@ ModifyConstraintActivitiesSameStartingTimeForm::ModifyConstraintActivitiesSameSt
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 	studentsComboBox->setCurrentIndex(0);
 
 	filterChanged();
