@@ -102,7 +102,8 @@ ModifyConstraintMinGapsBetweenActivitiesForm::ModifyConstraintMinGapsBetweenActi
 	}
 	activityTagsComboBox->setCurrentIndex(0);
 
-	studentsComboBox->addItem("");
+	populateStudentsComboBox(studentsComboBox, QString(""), true);
+	/*studentsComboBox->addItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -114,7 +115,7 @@ ModifyConstraintMinGapsBetweenActivitiesForm::ModifyConstraintMinGapsBetweenActi
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 	studentsComboBox->setCurrentIndex(0);
 
 	filterChanged();
