@@ -1,8 +1,8 @@
 /***************************************************************************
                           modifyconstraintstudentsmaxgapsperdayform.h  -  description
                              -------------------
-    begin                : Feb 11, 2005
-    copyright            : (C) 2005 by Lalescu Liviu
+    begin                : 2009
+    copyright            : (C) 2009 by Lalescu Liviu
     email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
