@@ -54,7 +54,8 @@ ModifyConstraintStudentsSetMaxBuildingChangesPerWeekForm::~ModifyConstraintStude
 }
 
 void ModifyConstraintStudentsSetMaxBuildingChangesPerWeekForm::updateStudentsComboBox(QWidget* parent){
-	studentsComboBox->clear();
+	int j=populateStudentsComboBox(studentsComboBox, this->_ctr->studentsName);
+	/*studentsComboBox->clear();
 	int i=0, j=-1;
 	for(int m=0; m<gt.rules.yearsList.size(); m++){
 		StudentsYear* sty=gt.rules.yearsList[m];
@@ -76,7 +77,7 @@ void ModifyConstraintStudentsSetMaxBuildingChangesPerWeekForm::updateStudentsCom
 				i++;
 			}
 		}
-	}
+	}*/
 	if(j<0)
 		showWarningForInvisibleSubgroupConstraint(parent, this->_ctr->studentsName);
 	else
