@@ -103,10 +103,10 @@ TimetableViewStudentsDaysHorizontalForm::TimetableViewStudentsDaysHorizontalForm
 	groupsListWidget->clear();
 	subgroupsListWidget->clear();
 	
-	//This connect should be lower in the code
+	//These connect-s should be lower in the code
 	//connect(yearsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(yearChanged(const QString&)));
-	connect(groupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(groupChanged(const QString&)));
-	connect(subgroupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(subgroupChanged(const QString&)));
+	//connect(groupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(groupChanged(const QString&)));
+	//connect(subgroupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(subgroupChanged(const QString&)));
 	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
 	connect(studentsTimetableTable, SIGNAL(currentItemChanged(QTableWidgetItem*, QTableWidgetItem*)), this, SLOT(currentItemChanged(QTableWidgetItem*, QTableWidgetItem*)));
 	connect(lockTimePushButton, SIGNAL(clicked()), this, SLOT(lockTime()));
@@ -183,7 +183,7 @@ TimetableViewStudentsDaysHorizontalForm::TimetableViewStudentsDaysHorizontalForm
 	//if(!columnResizeModeInitialized){
 	studentsTimetableTable->horizontalHeader()->setMinimumSectionSize(studentsTimetableTable->horizontalHeader()->defaultSectionSize());
 	//	columnResizeModeInitialized=true;
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
 	studentsTimetableTable->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
 #else
 	studentsTimetableTable->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
@@ -191,15 +191,32 @@ TimetableViewStudentsDaysHorizontalForm::TimetableViewStudentsDaysHorizontalForm
 	//}
 	///////////////
 	
+	//2019-12-11: so that the years' and groups' list widgets are not void, even if selecting to view by groups or subgroups.
 	yearsListWidget->clear();
 	for(int i=0; i<gt.rules.augmentedYearsList.size(); i++){
 		StudentsYear* sty=gt.rules.augmentedYearsList[i];
 		yearsListWidget->addItem(sty->name);
 	}
-	if(yearsListWidget->count()>0)
+	if(yearsListWidget->count()>0){
 		yearsListWidget->setCurrentRow(0);
-	connect(yearsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(yearChanged(const QString&)));
 		
+		groupsListWidget->clear();
+		for(StudentsGroup* stg : qAsConst(gt.rules.augmentedYearsList[0]->groupsList))
+			groupsListWidget->addItem(stg->name);
+		if(groupsListWidget->count()>0){
+			groupsListWidget->setCurrentRow(0);
+			
+			subgroupsListWidget->clear();
+			for(StudentsSubgroup* sts : qAsConst(gt.rules.augmentedYearsList[0]->groupsList.at(0)->subgroupsList))
+				subgroupsListWidget->addItem(sts->name);
+			if(subgroupsListWidget->count()>0)
+				subgroupsListWidget->setCurrentRow(0);
+		}
+	}
+	connect(yearsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(yearChanged(const QString&)));
+	connect(groupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(groupChanged(const QString&)));
+	connect(subgroupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(subgroupChanged(const QString&)));
+	
 	shownComboBox->addItem(tr("Years"));
 	shownComboBox->addItem(tr("Groups"));
 	shownComboBox->addItem(tr("Subgroups"));
@@ -328,7 +345,7 @@ void TimetableViewStudentsDaysHorizontalForm::newTimetableGenerated()
 	//if(!columnResizeModeInitialized){
 /*	studentsTimetableTable->horizontalHeader()->setMinimumSectionSize(studentsTimetableTable->horizontalHeader()->defaultSectionSize());
 	//	columnResizeModeInitialized=true;
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
 	studentsTimetableTable->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
 #else
 	studentsTimetableTable->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
@@ -610,9 +627,12 @@ void TimetableViewStudentsDaysHorizontalForm::updateStudentsTimetableTable(){
 
 	assert(sts);
 	int i;
-	for(i=0; i<gt.rules.nInternalSubgroups; i++)
+	/*for(i=0; i<gt.rules.nInternalSubgroups; i++)
 		if(gt.rules.internalSubgroupsList[i]==sts)
 			break;
+	assert(i==sts->indexInInternalSubgroupsList);*/
+	i=sts->indexInInternalSubgroupsList;
+	assert(i>=0);
 	assert(i<gt.rules.nInternalSubgroups);
 	for(int j=0; j<gt.rules.nHoursPerDay && j<studentsTimetableTable->rowCount(); j++){
 		for(int k=0; k<gt.rules.nDaysPerWeek && k<studentsTimetableTable->columnCount(); k++){
@@ -654,30 +674,37 @@ void TimetableViewStudentsDaysHorizontalForm::updateStudentsTimetableTable(){
 					//s+=tr("R:%1", "Room").arg(gt.rules.internalRoomsList[r]->name);
 					s+="\n";
 					s+=gt.rules.internalRoomsList[r]->name;
+
+					if(gt.rules.internalRoomsList[r]->isVirtual==true){
+						QStringList tsl;
+						for(int i : qAsConst(best_solution.realRoomsList[ai]))
+							tsl.append(gt.rules.internalRoomsList[i]->name);
+						s+=QString(" (")+tsl.join(", ")+QString(")");
+					}
 				}
 
 				//added by Volker Dirr (start)
 				QString descr="";
 				QString t="";
 				if(idsOfPermanentlyLockedTime.contains(act->id)){
-					descr+=QCoreApplication::translate("TimetableViewForm", "PLT", "Abbreviation for permanently locked time. There are 4 string: permanently locked time, permanently locked space, "
+					descr+=QCoreApplication::translate("TimetableViewForm", "PLT", "Abbreviation for permanently locked time. There are 4 strings: permanently locked time, permanently locked space, "
 						"locked time, locked space. Make sure their abbreviations contain different letters and are visually different, so user can easily differentiate between them."
 						" These abbreviations may appear also in other places, please use the same abbreviations.");
 					t=", ";
 				}
 				else if(idsOfLockedTime.contains(act->id)){
-					descr+=QCoreApplication::translate("TimetableViewForm", "LT", "Abbreviation for locked time. There are 4 string: permanently locked time, permanently locked space, "
+					descr+=QCoreApplication::translate("TimetableViewForm", "LT", "Abbreviation for locked time. There are 4 strings: permanently locked time, permanently locked space, "
 						"locked time, locked space. Make sure their abbreviations contain different letters and are visually different, so user can easily differentiate between them."
 						" These abbreviations may appear also in other places, please use the same abbreviations.");
 					t=", ";
 				}
 				if(idsOfPermanentlyLockedSpace.contains(act->id)){
-					descr+=t+QCoreApplication::translate("TimetableViewForm", "PLS", "Abbreviation for permanently locked space. There are 4 string: permanently locked time, permanently locked space, "
+					descr+=t+QCoreApplication::translate("TimetableViewForm", "PLS", "Abbreviation for permanently locked space. There are 4 strings: permanently locked time, permanently locked space, "
 						"locked time, locked space. Make sure their abbreviations contain different letters and are visually different, so user can easily differentiate between them."
 						" These abbreviations may appear also in other places, please use the same abbreviations.");
 				}
 				else if(idsOfLockedSpace.contains(act->id)){
-					descr+=t+QCoreApplication::translate("TimetableViewForm", "LS", "Abbreviation for locked space. There are 4 string: permanently locked time, permanently locked space, "
+					descr+=t+QCoreApplication::translate("TimetableViewForm", "LS", "Abbreviation for locked space. There are 4 strings: permanently locked time, permanently locked space, "
 						"locked time, locked space. Make sure their abbreviations contain different letters and are visually different, so user can easily differentiate between them."
 						" These abbreviations may appear also in other places, please use the same abbreviations.");
 				}
@@ -778,35 +805,54 @@ void TimetableViewStudentsDaysHorizontalForm::detailActivity(QTableWidgetItem* i
 	}
 
 	QString s;
-	QString yearname;
-	QString groupname;
+	//QString yearname; //not really necessary
+	//QString groupname; //not really necessary
 	QString subgroupname;
-
-	if(yearsListWidget->currentRow()<0 || yearsListWidget->currentRow()>=yearsListWidget->count())
-		return;
-	if(groupsListWidget->currentRow()<0 || groupsListWidget->currentRow()>=groupsListWidget->count())
-		return;
+	
+	//Note: the years and the groups list widgets might contain useless information if the user selected to see only groups or subgroups.
+	//However, in this case they are not void and the currentRow() will be 0 (first year) for the year list widget and, if the variant is
+	//to show only the subgroups, the same for the groups list widget (initialized in the dialog's constructor).
+	
+	//if(yearsListWidget->currentRow()<0 || yearsListWidget->currentRow()>=yearsListWidget->count())
+	//	return;
+	//if(groupsListWidget->currentRow()<0 || groupsListWidget->currentRow()>=groupsListWidget->count())
+	//	return;
 	if(subgroupsListWidget->currentRow()<0 || subgroupsListWidget->currentRow()>=subgroupsListWidget->count())
 		return;
 
-	yearname = yearsListWidget->currentItem()->text();
-	groupname = groupsListWidget->currentItem()->text();
+	//yearname = yearsListWidget->currentItem()->text();
+	//groupname = groupsListWidget->currentItem()->text();
 	subgroupname = subgroupsListWidget->currentItem()->text();
 
-	StudentsSubgroup* sts=(StudentsSubgroup*)gt.rules.searchAugmentedStudentsSet(subgroupname);
+	StudentsSet* ss=gt.rules.searchAugmentedStudentsSet(subgroupname);
+	if(ss==NULL){
+		QMessageBox::information(this, tr("FET warning"), tr("Inexistent subgroup - please reload this dialog"));
+		return;
+	}
+	if(ss->type!=STUDENTS_SUBGROUP){
+		QMessageBox::warning(this, tr("FET warning"), tr("Incorrect subgroup settings - please reload this dialog"));
+		return;
+	}
+	StudentsSubgroup* sts=(StudentsSubgroup*)ss;
+
+	/*StudentsSubgroup* sts=(StudentsSubgroup*)gt.rules.searchAugmentedStudentsSet(subgroupname);
 	if(!sts){
 		QMessageBox::warning(this, tr("FET warning"), tr("Invalid students set - please close this dialog and open a new view students timetable dialog"));
 		return;
-	}
+	}*/
+	
 	assert(sts);
 	int i;
-	for(i=0; i<gt.rules.nInternalSubgroups; i++)
+	/*for(i=0; i<gt.rules.nInternalSubgroups; i++)
 		if(gt.rules.internalSubgroupsList[i]==sts)
 			break;
+	assert(i==sts->indexInInternalSubgroupsList);*/
 /*	if(!(i<gt.rules.nInternalSubgroups)){
 		QMessageBox::warning(this, tr("FET warning"), tr("Invalid students set - please close this dialog and open a new view students dialog"));
 		return;
 	}*/
+	i=sts->indexInInternalSubgroupsList;
+	assert(i>=0);
 	assert(i<gt.rules.nInternalSubgroups);
 	int j=item->row();
 	int k=item->column();
@@ -820,11 +866,18 @@ void TimetableViewStudentsDaysHorizontalForm::detailActivity(QTableWidgetItem* i
 			//s+=act->getDetailedDescriptionWithConstraints(gt.rules);
 			s+=act->getDetailedDescription(gt.rules);
 
-			//int r=rooms_timetable_weekly[i][k][j];
 			int r=best_solution.rooms[ai];
 			if(r!=UNALLOCATED_SPACE && r!=UNSPECIFIED_ROOM){
 				s+="\n";
 				s+=tr("Room: %1").arg(gt.rules.internalRoomsList[r]->name);
+
+				if(gt.rules.internalRoomsList[r]->isVirtual==true){
+					QStringList tsl;
+					for(int i : qAsConst(best_solution.realRoomsList[ai]))
+						tsl.append(gt.rules.internalRoomsList[i]->name);
+					s+=QString(" (")+tsl.join(", ")+QString(")");
+				}
+
 				if(gt.rules.internalRoomsList[r]->building!=""){
 					s+="\n";
 					s+=tr("Building=%1").arg(gt.rules.internalRoomsList[r]->building);
@@ -905,39 +958,58 @@ void TimetableViewStudentsDaysHorizontalForm::lock(bool lockTime, bool lockSpace
 		return;
 	}
 
-	QString yearname;
-	QString groupname;
+	//QString yearname; //not really necessary
+	//QString groupname; //not really necessary
 	QString subgroupname;
 	
-	if(yearsListWidget->currentRow()<0 || yearsListWidget->currentRow()>=yearsListWidget->count()){
+	//Note: the years and the groups list widgets might contain useless information if the user selected to see only groups or subgroups.
+	//However, in this case they are not void and the currentRow() will be 0 (first year) for the year list widget and, if the variant is
+	//to show only the subgroups, the same for the groups list widget (initialized in the dialog's constructor).
+	
+	/*if(yearsListWidget->currentRow()<0 || yearsListWidget->currentRow()>=yearsListWidget->count()){
 		QMessageBox::information(this, tr("FET information"), tr("Please select a year"));
 		return;
 	}
 	if(groupsListWidget->currentRow()<0 || groupsListWidget->currentRow()>=groupsListWidget->count()){
 		QMessageBox::information(this, tr("FET information"), tr("Please select a group"));
 		return;
-	}
+	}*/
 	if(subgroupsListWidget->currentRow()<0 || subgroupsListWidget->currentRow()>=subgroupsListWidget->count()){
 		QMessageBox::information(this, tr("FET information"), tr("Please select a subgroup"));
 		return;
 	}
 
-	yearname = yearsListWidget->currentItem()->text();
-	groupname = groupsListWidget->currentItem()->text();
+	//yearname = yearsListWidget->currentItem()->text();
+	//groupname = groupsListWidget->currentItem()->text();
 	subgroupname = subgroupsListWidget->currentItem()->text();
 
 	Solution* tc=&best_solution;
 
-	StudentsSubgroup* sts=(StudentsSubgroup*)gt.rules.searchAugmentedStudentsSet(subgroupname);
+	StudentsSet* ss=gt.rules.searchAugmentedStudentsSet(subgroupname);
+	if(ss==NULL){
+		QMessageBox::information(this, tr("FET warning"), tr("Inexistent subgroup - please reload this dialog"));
+		return;
+	}
+	if(ss->type!=STUDENTS_SUBGROUP){
+		QMessageBox::warning(this, tr("FET warning"), tr("Incorrect subgroup settings - please reload this dialog"));
+		return;
+	}
+	StudentsSubgroup* sts=(StudentsSubgroup*)ss;
+
+	/*StudentsSubgroup* sts=(StudentsSubgroup*)gt.rules.searchAugmentedStudentsSet(subgroupname);
 	if(!sts){
 		QMessageBox::warning(this, tr("FET warning"), tr("Invalid students set - please close this dialog and open a new view students timetable dialog"));
 		return;
-	}
+	}*/
+	
 	assert(sts);
 	int i;
-	for(i=0; i<gt.rules.nInternalSubgroups; i++)
+	/*for(i=0; i<gt.rules.nInternalSubgroups; i++)
 		if(gt.rules.internalSubgroupsList[i]==sts)
 			break;
+	assert(i==sts->indexInInternalSubgroupsList);*/
+	i=sts->indexInInternalSubgroupsList;
+	assert(i>=0);
 	assert(i<gt.rules.nInternalSubgroups);
 
 	bool report=false; //the messages are annoying
@@ -1032,7 +1104,14 @@ void TimetableViewStudentsDaysHorizontalForm::lock(bool lockTime, bool lockSpace
 
 					int ri=tc->rooms[ai];
 					if(ri!=UNALLOCATED_SPACE && ri!=UNSPECIFIED_ROOM && lockSpace){
-						ConstraintActivityPreferredRoom* ctr=new ConstraintActivityPreferredRoom(100, act->id, (gt.rules.internalRoomsList[ri])->name, false);
+						QStringList tl;
+						if(gt.rules.internalRoomsList[ri]->isVirtual==false)
+							assert(tc->realRoomsList[ai].isEmpty());
+						else
+							for(int rr : qAsConst(tc->realRoomsList[ai]))
+								tl.append(gt.rules.internalRoomsList[rr]->name);
+						
+						ConstraintActivityPreferredRoom* ctr=new ConstraintActivityPreferredRoom(100, act->id, (gt.rules.internalRoomsList[ri])->name, tl, false);
 						bool t=gt.rules.addSpaceConstraint(ctr);
 
 						QString s;
@@ -1051,7 +1130,9 @@ void TimetableViewStudentsDaysHorizontalForm::lock(bool lockTime, bool lockSpace
 
 							for(ConstraintActivityPreferredRoom* c : gt.rules.aprHash.value(act->id, QSet<ConstraintActivityPreferredRoom*>())){
 								assert(c->activityId==act->id);
-								if(c->activityId==act->id && c->weightPercentage==100.0 && c->active){
+								if(c->activityId==act->id && c->weightPercentage==100.0 && c->active
+								 && (gt.rules.internalRoomsList[ri]->isVirtual==false
+								 || (gt.rules.internalRoomsList[ri]->isVirtual==true && !c->preferredRealRoomsNames.isEmpty()))){
 									count++;
 									if(c->permanentlyLocked){
 										if(idsOfLockedSpace.contains(c->activityId) || !idsOfPermanentlyLockedSpace.contains(c->activityId)){
@@ -1136,7 +1217,7 @@ void TimetableViewStudentsDaysHorizontalForm::lock(bool lockTime, bool lockSpace
 		}
 	}
 	else{
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
 		if(addedT>0){
 			added << QCoreApplication::translate("TimetableViewForm", "Added %n locking time constraint(s).",
 			 "See http://doc.qt.io/qt-5/i18n-plural-rules.html for advice on how to correctly translate this field."
