@@ -30,6 +30,7 @@ class TimetableViewStudentsDaysHorizontalForm : public QDialog, public Ui::Timet
 
 public:
 	TimetableViewStudentsDaysHorizontalForm(QWidget* parent);
+	void newTimetableGenerated();
 	~TimetableViewStudentsDaysHorizontalForm();
 
 	void lock(bool lockTime, bool lockSpace);
@@ -51,6 +52,8 @@ public slots:
 	void currentItemChanged(QTableWidgetItem* current, QTableWidgetItem* previous);
 
 	void help();
+	
+	void shownComboBoxChanged(QString shownCategory);
 
 protected:
 	void resizeEvent(QResizeEvent* event);
