@@ -344,7 +344,7 @@ TimetableViewStudentsTimeHorizontalForm::TimetableViewStudentsTimeHorizontalForm
 		
 	widthSpinBox->setSuffix(QString(" ")+tr("px", "Abbreviation for pixels"));
 	widthSpinBox->setMinimum(MINIMUM_WIDTH_SPIN_BOX_VALUE);
-#if QT_VERSION >= 0x050200
+#if QT_VERSION >= QT_VERSION_CHECK(5,2,0)
 	widthSpinBox->setMaximum(studentsTimetableTable->verticalHeader()->maximumSectionSize());
 #else
 	widthSpinBox->setMaximum(maxScreenWidth(this));
@@ -354,7 +354,7 @@ TimetableViewStudentsTimeHorizontalForm::TimetableViewStudentsTimeHorizontalForm
 	
 	heightSpinBox->setSuffix(QString(" ")+tr("px", "Abbreviation for pixels"));
 	heightSpinBox->setMinimum(MINIMUM_HEIGHT_SPIN_BOX_VALUE);
-#if QT_VERSION >= 0x050200
+#if QT_VERSION >= QT_VERSION_CHECK(5,2,0)
 	heightSpinBox->setMaximum(studentsTimetableTable->verticalHeader()->maximumSectionSize());
 #else
 	heightSpinBox->setMaximum(maxScreenWidth(this));
@@ -371,7 +371,7 @@ TimetableViewStudentsTimeHorizontalForm::TimetableViewStudentsTimeHorizontalForm
 //	teachersTimetableTable->verticalHeader()->setDefaultSectionSize(h);
 //	teachersTimetableTable->horizontalHeader()->setDefaultSectionSize(w);
 
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
 	studentsTimetableTable->verticalHeader()->setSectionResizeMode(QHeaderView::Interactive);
 	studentsTimetableTable->horizontalHeader()->setSectionResizeMode(QHeaderView::Interactive);
 #else
@@ -622,7 +622,7 @@ void TimetableViewStudentsTimeHorizontalForm::newTimetableGenerated()
 		
 	widthSpinBox->setSuffix(QString(" ")+tr("px", "Abbreviation for pixels"));
 	widthSpinBox->setMinimum(MINIMUM_WIDTH_SPIN_BOX_VALUE);
-#if QT_VERSION >= 0x050200
+#if QT_VERSION >= QT_VERSION_CHECK(5,2,0)
 	widthSpinBox->setMaximum(studentsTimetableTable->verticalHeader()->maximumSectionSize());
 #else
 	widthSpinBox->setMaximum(maxScreenWidth(this));
@@ -632,7 +632,7 @@ void TimetableViewStudentsTimeHorizontalForm::newTimetableGenerated()
 	
 	heightSpinBox->setSuffix(QString(" ")+tr("px", "Abbreviation for pixels"));
 	heightSpinBox->setMinimum(MINIMUM_HEIGHT_SPIN_BOX_VALUE);
-#if QT_VERSION >= 0x050200
+#if QT_VERSION >= QT_VERSION_CHECK(5,2,0)
 	heightSpinBox->setMaximum(studentsTimetableTable->verticalHeader()->maximumSectionSize());
 #else
 	heightSpinBox->setMaximum(maxScreenWidth(this));
@@ -649,7 +649,7 @@ void TimetableViewStudentsTimeHorizontalForm::newTimetableGenerated()
 //	teachersTimetableTable->verticalHeader()->setDefaultSectionSize(h);
 //	teachersTimetableTable->horizontalHeader()->setDefaultSectionSize(w);
 
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
 	studentsTimetableTable->verticalHeader()->setSectionResizeMode(QHeaderView::Interactive);
 	studentsTimetableTable->horizontalHeader()->setSectionResizeMode(QHeaderView::Interactive);
 #else
@@ -855,24 +855,24 @@ void TimetableViewStudentsTimeHorizontalForm::updateStudentsTimetableTable(){
 					QString descr="";
 					QString tt="";
 					if(idsOfPermanentlyLockedTime.contains(act->id)){
-						descr+=QCoreApplication::translate("TimetableViewForm", "PLT", "Abbreviation for permanently locked time. There are 4 string: permanently locked time, permanently locked space, "
+						descr+=QCoreApplication::translate("TimetableViewForm", "PLT", "Abbreviation for permanently locked time. There are 4 strings: permanently locked time, permanently locked space, "
 							"locked time, locked space. Make sure their abbreviations contain different letters and are visually different, so user can easily differentiate between them."
 							" These abbreviations may appear also in other places, please use the same abbreviations.");
 						tt=", ";
 					}
 					else if(idsOfLockedTime.contains(act->id)){
-						descr+=QCoreApplication::translate("TimetableViewForm", "LT", "Abbreviation for locked time. There are 4 string: permanently locked time, permanently locked space, "
+						descr+=QCoreApplication::translate("TimetableViewForm", "LT", "Abbreviation for locked time. There are 4 strings: permanently locked time, permanently locked space, "
 						"locked time, locked space. Make sure their abbreviations contain different letters and are visually different, so user can easily differentiate between them."
 							" These abbreviations may appear also in other places, please use the same abbreviations.");
 						tt=", ";
 					}
 					if(idsOfPermanentlyLockedSpace.contains(act->id)){
-						descr+=tt+QCoreApplication::translate("TimetableViewForm", "PLS", "Abbreviation for permanently locked space. There are 4 string: permanently locked time, permanently locked space, "
+						descr+=tt+QCoreApplication::translate("TimetableViewForm", "PLS", "Abbreviation for permanently locked space. There are 4 strings: permanently locked time, permanently locked space, "
 							"locked time, locked space. Make sure their abbreviations contain different letters and are visually different, so user can easily differentiate between them."
 							" These abbreviations may appear also in other places, please use the same abbreviations.");
 					}
 					else if(idsOfLockedSpace.contains(act->id)){
-						descr+=tt+QCoreApplication::translate("TimetableViewForm", "LS", "Abbreviation for locked space. There are 4 string: permanently locked time, permanently locked space, "
+						descr+=tt+QCoreApplication::translate("TimetableViewForm", "LS", "Abbreviation for locked space. There are 4 strings: permanently locked time, permanently locked space, "
 							"locked time, locked space. Make sure their abbreviations contain different letters and are visually different, so user can easily differentiate between them."
 							" These abbreviations may appear also in other places, please use the same abbreviations.");
 					}
@@ -1097,11 +1097,18 @@ void TimetableViewStudentsTimeHorizontalForm::detailActivity(QTableWidgetItem* i
 			//s += act->getDetailedDescriptionWithConstraints(gt.rules);
 			s += act->getDetailedDescription(gt.rules);
 
-			//int r=rooms_timetable_weekly[teacher][k][j];
 			int r=best_solution.rooms[ai];
 			if(r!=UNALLOCATED_SPACE && r!=UNSPECIFIED_ROOM){
 				s+="\n";
 				s+=tr("Room: %1").arg(gt.rules.internalRoomsList[r]->name);
+
+				if(gt.rules.internalRoomsList[r]->isVirtual==true){
+					QStringList tsl;
+					for(int i : qAsConst(best_solution.realRoomsList[ai]))
+						tsl.append(gt.rules.internalRoomsList[i]->name);
+					s+=QString(" (")+tsl.join(", ")+QString(")");
+				}
+
 				if(gt.rules.internalRoomsList[r]->building!=""){
 					s+="\n";
 					s+=tr("Building=%1").arg(gt.rules.internalRoomsList[r]->building);
@@ -1382,7 +1389,9 @@ void TimetableViewStudentsTimeHorizontalForm::lock(bool lockTime, bool lockSpace
 				for(ConstraintActivityPreferredRoom* c : gt.rules.aprHash.value(act->id, QSet<ConstraintActivityPreferredRoom*>())){
 					assert(c->activityId==act->id);
 
-					if(c->activityId==act->id && c->weightPercentage==100.0 && c->active){
+					if(c->activityId==act->id && c->weightPercentage==100.0 && c->active
+					 && (gt.rules.internalRoomsList[ri]->isVirtual==false
+					 || (gt.rules.internalRoomsList[ri]->isVirtual==true && !c->preferredRealRoomsNames.isEmpty()))){
 						count++;
 						if(c->permanentlyLocked){
 							if(idsOfLockedSpace.contains(c->activityId) || !idsOfPermanentlyLockedSpace.contains(c->activityId)){
@@ -1415,7 +1424,14 @@ void TimetableViewStudentsTimeHorizontalForm::lock(bool lockTime, bool lockSpace
 					}
 				}
 				if(count==0 && (lockRadioButton->isChecked() || toggleRadioButton->isChecked())){
-					ConstraintActivityPreferredRoom* ctr=new ConstraintActivityPreferredRoom(100, act->id, (gt.rules.internalRoomsList[ri])->name, false);
+					QStringList tl;
+					if(gt.rules.internalRoomsList[ri]->isVirtual==false)
+						assert(tc->realRoomsList[ai].isEmpty());
+					else
+						for(int rr : qAsConst(tc->realRoomsList[ai]))
+							tl.append(gt.rules.internalRoomsList[rr]->name);
+					
+					ConstraintActivityPreferredRoom* ctr=new ConstraintActivityPreferredRoom(100, act->id, (gt.rules.internalRoomsList[ri])->name, tl, false);
 					bool t=gt.rules.addSpaceConstraint(ctr);
 	
 					QString s;
@@ -1488,7 +1504,7 @@ void TimetableViewStudentsTimeHorizontalForm::lock(bool lockTime, bool lockSpace
 		}
 	}
 	else{
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
 		if(addedT>0){
 			added << QCoreApplication::translate("TimetableViewForm", "Added %n locking time constraint(s).",
 			 "See http://doc.qt.io/qt-5/i18n-plural-rules.html for advice on how to correctly translate this field."
